@@ -70,6 +70,15 @@ def notify():
 @click.option('--send-mail', is_flag=True, default=False)
 def apply(for_real, send_mail):
     """Appliquer les politiques de FUP pour tous les clients Business"""
+
+    def str_data(conso_bytes):
+        result = round(conso_bytes/1000000000, 2)
+        result = str(result).replace('.', ',')
+        if result == '0,0':
+            return '0'
+        else:
+            return result
+
     result = {}
     products = Product.all()
     for product in products:
@@ -99,8 +108,14 @@ def apply(for_real, send_mail):
             'data_limit',
             'policy_name',
             'customer',
-            'download',
-            'upload',
+            'download_international',
+            'download_cache',
+            'download_national',
+            'upload_international',
+            'upload_cache',
+            'upload_national',
+            'total_download_for_fup',
+            'total_upload_for_fup',
             'total',
             'status'
             ]
@@ -133,15 +148,38 @@ def apply(for_real, send_mail):
                             reverse=True
                             )
                         policy_status = customer_policy_status[0]['status']
+
+                    conso = {
+                        'internet': {'octets_in': 0, 'octets_out': 0},
+                        'national': {'octets_in': 0, 'octets_out': 0},
+                        'cache': {'octets_in': 0, 'octets_out': 0}
+                    }
+                    for source in data['sources']:
+                        source_name = source['source']
+                        octets_in = source['octets_in']
+                        octets_out = source['octets_out']
+                        conso[source_name] = source
+                        conso[source_name]['octets_in'] = str_data(octets_in)
+                        conso[source_name]['octets_out'] = str_data(octets_out)
+                    click.echo(conso)
+                    total_octets_in = str_data(data['octets_in'])
+                    total_octets_out = str_data(data['octets_out'])
+                    total = str_data(data['total'])
                     dataset.append(
                         [
                             product,
                             str(policy['data_limit']).replace('.', ','),
                             policy['name'],
                             customer,
-                            str(data['octets_in']).replace('.', ','),
-                            str(data['octets_out']).replace('.', ','),
-                            str(data['total']).replace('.', ','),
+                            conso['internet']['octets_in'],
+                            conso['cache']['octets_in'],
+                            conso['national']['octets_in'],
+                            conso['internet']['octets_out'],
+                            conso['cache']['octets_out'],
+                            conso['national']['octets_out'],
+                            total_octets_in,
+                            total_octets_out,
+                            total,
                             policy_status
                             ]
                         )
