@@ -83,4 +83,44 @@ FUPDB_CREDENTIALS = {
 
 REST_CLIENT = RestClient(AIGUILLIER_URL)
 
+RAPPORT_HTML = """
+<!DOCTYPE html>
+<html>
+  <head>
+    <meta charset="utf-8"/>
+  </head>
+  <h1>Rapport FUP du {{date}}</h1>
+
+  {% for product in products %}
+  <p>
+    <h2>Produit: {{ product }}</h2>
+    {% for p, policies in result.items() %}
+    {% for policy in policies %}
+    {% set flag = False %}
+    <p>
+      <h3>Limite autorisée: {{ policy.data_limit }} Go</h3>
+        <ul>
+          {% for customer, data in policy.customers.items() %}
+          {% if data.fup_in %}
+          {% set flag = True %}
+          <li>
+            {{ customer }}: {{ data.total }} Go (fup_in)
+          </li>
+          {% elif data.fup_out %}
+          {% set flag = True %}
+          <li>
+            {{ customer }}: {{ data.total }} Go (fup_out)
+          </li>
+          {% endif %}
+          {% endfor %}
+        </ul>
+        {% if not flag %}<p>Aucun client à restreindre/libérer</p>{% endif %}
+    </p>
+    {% endfor %}
+    {% endfor %}
+  </p>
+  {% endfor %}
+</html>
+"""
+
 # EOF
